'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _compose = require('recompose/compose');

var _compose2 = _interopRequireDefault(_compose);

var _withPropsOnChange = require('recompose/withPropsOnChange');

var _withPropsOnChange2 = _interopRequireDefault(_withPropsOnChange);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Create an event handler prop that, when called, directs react-router to
// change locations. Must follow the `withRouter` HOC in the `compose()` chain.

function createLocationDescriptor(to, query, hash, state) {
  if (query || hash || state) {
    return { pathname: to, query, hash, state };
  } else {
    return to;
  }
}
exports.default = function withRouterLink(eventType = 'onClick', action = 'push') {
  return (0, _compose2.default)((0, _withPropsOnChange2.default)(["to", "query", "hash", "state", "children", "target", "router", "onlyActiveOnIndex", eventType], function (props) {
    const { to, query, hash, state, children, target, router, onlyActiveOnIndex } = props;

    function actionHandler(event) {
      // Delegate to child event handlers
      if (children == null ? null : children.props[eventType]) children.props[eventType](event);
      if (props[eventType]) props[eventType](event);
      if (!to) return;
      if (target || event.defaultPrevented) return;
      event.preventDefault();
      return router[action](createLocationDescriptor(to, query, hash, state));
    }const mergedProps = {};
    mergedProps[eventType] = actionHandler;
    if (to) {
      mergedProps.href = router.createHref(to);
      if (props.active === undefined) {
        mergedProps.active = router.isActive(to, onlyActiveOnIndex);
      }
    }return mergedProps;
  }));
};